@@ -35,3 +35,13 @@ def random_a_recordset_name(zone_name, recordset_name='testrecord'):
 
 def random_blacklist(name='testblacklist'):
     return '{0}{1}'.format(name, random_digits())
+
+
+def random_zone_file(name='testzoneimport'):
+    return "$ORIGIN {0}{1}.com.\n" \
+           "$TTL 300\n" \
+           "{0}{1}.com. 300 IN SOA ns.{0}{1}.com. nsadmin.{0}{1}.com. 42 42 42 42 42\n" \
+           "{0}{1}.com. 300 IN NS ns.{0}{1}.com.\n" \
+           "{0}{1}.com. 300 IN MX 10 mail.{0}{1}.com.\n" \
+           "ns.{0}{1}.com. 300 IN A 10.0.0.1\n" \
+           "mail.{0}{1}.com. 300 IN A 10.0.0.2\n".format(name, random_digits())
